@@ -1,14 +1,19 @@
+# -*- coding: utf-8 -*-
+# Copyright (c) 2016 Łukasz Rogalski <rogalski.91@gmail.com>
+# Copyright (c) 2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2016 Luis Escobar <lescobar@vauxoo.com>
+
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
 
 import linecache
 
-from pylint.checkers.base import BaseChecker
+from pylint import checkers
 from pylint.interfaces import IAstroidChecker, HIGH
 from pylint.checkers.utils import check_messages
 
 
-class DocStringStyleChecker(BaseChecker):
+class DocStringStyleChecker(checkers.BaseChecker):
     """Checks format of docstrings based on PEP 0257"""
 
     __implements__ = IAstroidChecker
@@ -31,7 +36,7 @@ class DocStringStyleChecker(BaseChecker):
         self._check_docstring('class', node)
 
     def visit_functiondef(self, node):
-        ftype = node.is_method() and 'method' or 'function'
+        ftype = 'method' if node.is_method() else 'function'
         self._check_docstring(ftype, node)
 
     visit_asyncfunctiondef = visit_functiondef
