@@ -1,3 +1,10 @@
+# Copyright (c) 2006, 2008, 2010, 2013-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2014 Brett Cannon <brett@python.org>
+# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
+# Copyright (c) 2015-2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2017 hippo91 <guillaume.peillex@gmail.com>
+
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
 
@@ -186,7 +193,7 @@ class LocalsVisitor(ASTWalker):
     def visit(self, node):
         """launch the visit starting from the given node"""
         if node in self._visited:
-            return
+            return None
         self._visited[node] = 1 # FIXME: use set ?
         methods = self.get_callbacks(node)
         if methods[0] is not None:
@@ -196,3 +203,4 @@ class LocalsVisitor(ASTWalker):
                 self.visit(local_node)
         if methods[1] is not None:
             return methods[1](node)
+        return None
