@@ -1,6 +1,13 @@
-# Copyright (c) 2014, 2016 Google, Inc.
-# Copyright (c) 2015 Dmitry Pribysh <dmand@yandex.ru>
+# -*- coding: utf-8 -*-
+# Copyright (c) 2014 Google, Inc.
+# Copyright (c) 2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2014 Holger Peters <email@holger-peters.de>
 # Copyright (c) 2015-2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015 Dmitry Pribysh <dmand@yandex.ru>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
+# Copyright (c) 2016 Filipe Brandenburger <filbranden@google.com>
+# Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -16,6 +23,20 @@ from pylint.checkers import typecheck
 from pylint.testutils import CheckerTestCase, Message, set_config
 
 
+def c_extension_missing():
+    """Coverage module has C-extension, which we can reuse for test"""
+    try:
+        import coverage.tracer as _
+        return False
+    except ImportError:
+        _ = None
+        return True
+
+
+needs_c_extension = pytest.mark.skipif(c_extension_missing(),
+                                       reason='Requires coverage (source of C-extension)')
+
+
 class TestTypeChecker(CheckerTestCase):
     "Tests for pylint.checkers.typecheck"
     CHECKER_CLASS = typecheck.TypeChecker
@@ -99,6 +120,30 @@ class TestTypeChecker(CheckerTestCase):
         with self.assertNoMessages():
             self.checker.visit_attribute(node)
 
+    @set_config(suggestion_mode=False)
+    @needs_c_extension
+    def test_nomember_on_c_extension_error_msg(self):
+        node = astroid.extract_node('''
+        from coverage import tracer
+        tracer.CTracer  #@
+        ''')
+        message = Message('no-member', node=node,
+                          args=('Module', 'coverage.tracer', 'CTracer', ''))
+        with self.assertAddsMessages(message):
+            self.checker.visit_attribute(node)
+
+    @set_config(suggestion_mode=True)
+    @needs_c_extension
+    def test_nomember_on_c_extension_info_msg(self):
+        node = astroid.extract_node('''
+        from coverage import tracer
+        tracer.CTracer  #@
+        ''')
+        message = Message('c-extension-no-member', node=node,
+                          args=('Module', 'coverage.tracer', 'CTracer', ''))
+        with self.assertAddsMessages(message):
+            self.checker.visit_attribute(node)
+
     @set_config(contextmanager_decorators=('contextlib.contextmanager',
                                            '.custom_contextmanager'))
     def test_custom_context_manager(self):
